@@ -265,7 +265,7 @@ sub preprocess {
 		$pagestate{$page}{meta}{title} = decode_entities($params{subject});
 	}
 
-	if ($params{page} =~ m/\/\Q$config{comments_pagename}\E\d+_/) {
+	if ($params{page} =~ m/\/\Q$config{comments_pagename}\E\d+/) {
 		$pagestate{$page}{meta}{permalink} = urlto(IkiWiki::dirname($params{page})).
 			"#".page_to_id($params{page});
 	}
@@ -326,7 +326,6 @@ sub editcomment ($$) {
 	my $form = CGI::FormBuilder->new(
 		fields => [qw{do sid page subject editcontent type author
 			email url subscribe anonsubscribe}],
-		charset => 'utf-8',
 		method => 'POST',
 		required => [qw{editcontent}],
 		javascript => 0,
@@ -581,7 +580,7 @@ sub editcomment ($$) {
 			IkiWiki::refresh();
 			IkiWiki::saveindex();
 
-			IkiWiki::printheader($session);
+			IkiWiki::printheader($session, 202); # HTTP 202: Accepted, but not processed
 			print IkiWiki::cgitemplate($cgi, gettext(gettext("comment stored for moderation")),
 				"<p>".
 				gettext("Your comment will be posted after moderator review").
